@@ -34,13 +34,15 @@ def main(clear_conf=('c', False, 'Rewrite example config and noise'),
     conf = settings.get_conf()
     if conf['file']['keep']:
         dest_dir = os.path.expanduser(conf['file']['dir'])
-        if not os.path.exists:
+        if not os.path.exists(dest_dir):
             os.mkdir(dest_dir)
         dest = os.path.join(dest_dir, filename)
         shutil.move(local_image, dest)
     else:
         os.unlink(local_image)
-    utils.play_noise()
+
+    if conf['upload']['noise']:
+        utils.play_noise()
 
 def dispatch():
     main.command()
